xquery version "3.1";
(:~
: This module serves for displaying the information about a BdN author that
: is stored in his specific XML-file (/db/apps/sade/templates/authors/author.xml).
:
: @author Michelle Weidling
: @version 1.0
:)
module namespace authors="https://bdn-edition.de/ns/authors";

declare namespace bdn="http://www.bdn-edition.de/ns/1.0";
declare namespace templates="http://exist-db.org/xquery/templates";
declare namespace xhtml="http://www.w3.org/1999/xhtml";

import module namespace config="https://sade.textgrid.de/ns/config" at "../config.xqm";

declare variable $authors:img-path := "templates/img/";

declare function authors:show($node as node(), $model as map(*))
{
  let $author := request:get-parameter("id", "")
  let $file := authors:get-file($author)
  let $root := $file/*
  let $html := authors:render($root)
  return $html
};


declare function authors:get-file($author as xs:string) as document-node()?
{
  let $path := $config:app-root || "templates/authors/" || $author || ".xml"
  return doc($path)
};


(:~
 : Transforms the given TEI-XML to XHTML.
 :
 : @author Michelle Weidling
 : @param $nodes The current node of the TEI-XML
 : @return the respective XHTML element
 :)
declare function authors:render($nodes as node()*) as item()*
{
  for $node in $nodes return
  typeswitch ($node)
  case text() return
    $node

  case element(root) return
    authors:render($node/node())

  case element(header) return
    element{"div"}{
      attribute{"class"}{"block-header"},
      element{"h2"}{
        authors:render($node/node())
      }
    }

  case element(author) return
    element{"span"}{
      attribute{"style"}{"text-transform: uppercase;"},
      authors:render($node/node())
    }

  case element(title) return
  (element{"br"}{},
  element{"strong"}{
  authors:render($node/node())
  })

  case element(info) return
    (element{"br"}{},
    element{"span"}{
      authors:render($node/node())
    })

  case element(sup) return
    element{"sup"}{
      authors:render($node/node())
    }

  case element(images) return
    element{"div"}{
      attribute{"class"}{"col-xs-12 col-lg-4"},
      attribute{"style"}{"width: 25%;"},
        element{"div"}{
          attribute{"class"}{"pull-left"},
          authors:render($node/node())
      }
    }

  case element(img) return
    (element{"img"}{
      attribute{"src"}{$authors:img-path || $node/@src},
      attribute{"class"}{"img-about"},
      if (count($node/../img) gt 1 and $node/../img[1] = $node)
        then
          attribute{"style"}{"margin-bottom: 20px;"}
        else
          ()
    },
    if (count($node/../img) gt 1 and $node/../img[1] = $node)
      then
        element{"br"}{}
      else
        ())

  case element(description) return
    element{"div"}{
      if ($node/preceding::images)
        then
          attribute{"class"}{"col-xs-12 col-lg-8"}
        else
          attribute{"class"}{"col-xs-12 col-lg-12"},
      authors:render($node/node())
    }

  case element(p) return
    element{"p"}{
      authors:render($node/node())
    }

  case element(published) return
    if ($node/text()) then
      element xhtml:a
      {
        attribute href {$node/text()},
        attribute class {"edition-link"},
        <i class="fas fa-link"></i>,
        text{" Zur Edition"}
      }
    else
    ()

  default return
    ()
};
